containertools.get_element_starting_at_exactly_prolated_offset
==============================================================

.. autofunction:: abjad.tools.containertools.get_element_starting_at_exactly_prolated_offset.get_element_starting_at_exactly_prolated_offset
